@@ -22,6 +22,7 @@
 import abc
 import collections
 import glob
+import logging
 import os
 import shutil
 from typing import Any, Callable
@@ -33,7 +34,7 @@ import molecule.scenarios
 from molecule import config, logger, text, util
 from molecule.console import should_do_markup
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 MOLECULE_GLOB = os.environ.get("MOLECULE_GLOB", "molecule/*/molecule.yml")
 MOLECULE_DEFAULT_SCENARIO_NAME = "default"
 
@@ -41,7 +42,7 @@ MOLECULE_DEFAULT_SCENARIO_NAME = "default"
 class Base(object, metaclass=abc.ABCMeta):
     """An abstract base class used to define the command interface."""
 
-    def __init__(self, c):
+    def __init__(self, c: config.Config):
         """
         Initialize code for all command classes.
 
@@ -61,7 +62,7 @@ class Base(object, metaclass=abc.ABCMeta):
     def execute(self):  # pragma: no cover
         pass
 
-    def _setup(self):
+    def _setup(self) -> None:
         """
         Prepare Molecule's provisioner and returns None.
 
