@@ -19,14 +19,16 @@
 #  DEALINGS IN THE SOFTWARE.
 """Idempotence Command Module."""
 
+import logging
 import re
 
 import click
 
-from molecule import logger, util
+from molecule import util
 from molecule.command import base
+from molecule.text import strip_ansi_escape
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class Idempotence(base.Base):
@@ -73,17 +75,16 @@ class Idempotence(base.Base):
 
         :return: None
         """
-        self.print_info()
         if not self._config.state.converged:
             msg = "Instances not converged.  Please converge instances first."
             util.sysexit_with_message(msg)
 
-        output = self._config.provisioner.converge(out=None, err=None)
+        output = self._config.provisioner.converge()
 
         idempotent = self._is_idempotent(output)
         if idempotent:
             msg = "Idempotence completed successfully."
-            LOG.success(msg)
+            LOG.info(msg)
         else:
             msg = (
                 "Idempotence test failed because of the following tasks:\n" u"{}"
@@ -119,7 +120,7 @@ class Idempotence(base.Base):
         output = re.sub(r"\n\s*\n*", "\n", output)
 
         # Remove ansi escape sequences.
-        output = util.strip_ansi_escape(output)
+        output = strip_ansi_escape(output)
 
         # Split the output into a list and go through it.
         output_lines = output.split("\n")
