@@ -19,19 +19,23 @@
 #  DEALINGS IN THE SOFTWARE.
 """Config Module."""
 
+import copy
+import functools
+import logging
 import os
+from typing import Callable, MutableMapping, TypeVar
 from uuid import uuid4
 
 from packaging.version import Version
 
-from molecule import api, interpolation, logger, platforms, scenario, state, util
+from molecule import api, interpolation, platforms, scenario, state, util
 from molecule.constants import RC_SETUP_ERROR
 from molecule.dependency import ansible_galaxy, shell
 from molecule.model import schema_v3
 from molecule.provisioner import ansible
 from molecule.util import boolean, lru_cache, run_command, sysexit
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 MOLECULE_DEBUG = boolean(os.environ.get("MOLECULE_DEBUG", "False"))
 MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
 MOLECULE_DIRECTORY = "molecule"
@@ -39,6 +43,14 @@ MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
 DEFAULT_DRIVER = "delegated"
 
+T = TypeVar("T")
+
+
+# see https://github.com/python/mypy/issues/5858
+def cache(func: Callable[..., T]) -> T:
+    """Decorate properties to cache them."""
+    return functools.lru_cache()(func)  # type: ignore
+
 
 # https://stackoverflow.com/questions/16017397/injecting-function-call-after-init-with-decorator  # noqa
 class NewInitCaller(type):
@@ -67,7 +79,9 @@ class Config(object, metaclass=NewInitCaller):
     :ref:`root_scenario`, and State_ references.
     """
 
-    def __init__(self, molecule_file, args={}, command_args={}, ansible_args=()):
+    # pylint: disable=too-many-instance-attributes
+    # Config objects should be allowed to have any number of attributes
+    def __init__(self, molecule_file: str, args={}, command_args={}, ansible_args=()):
         """
         Initialize a new config class and returns None.
 
@@ -88,13 +102,14 @@ class Config(object, metaclass=NewInitCaller):
         self.config = self._get_config()
         self._action = None
         self._run_uuid = str(uuid4())
+        self.project_directory = os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
 
     def after_init(self):
         self.config = self._reget_config()
         if self.molecule_file:
             self._validate()
 
-    def write(self):
+    def write(self) -> None:
         util.write_file(self.config_file, util.safe_dump(self.config))
 
     @property
@@ -134,10 +149,6 @@ class Config(object, metaclass=NewInitCaller):
     def action(self, value):
         self._action = value
 
-    @property
-    def project_directory(self):
-        return os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
-
     @property
     def cache_directory(self):
         return "molecule_parallel" if self.is_parallel else "molecule"
@@ -198,7 +209,7 @@ class Config(object, metaclass=NewInitCaller):
         return platforms.Platforms(self, parallelize_platforms=self.is_parallel)
 
     @property  # type: ignore
-    @util.lru_cache()
+    @cache
     def provisioner(self):
         provisioner_name = self.config["provisioner"]["name"]
         if provisioner_name == "ansible":
@@ -239,7 +250,7 @@ class Config(object, metaclass=NewInitCaller):
 
         return driver_name
 
-    def _get_config(self):
+    def _get_config(self) -> MutableMapping:
         """
         Perform a prioritized recursive merge of config files.
 
@@ -264,7 +275,7 @@ class Config(object, metaclass=NewInitCaller):
 
         return self._combine(env=env)
 
-    def _combine(self, env=os.environ, keep_string=None):
+    def _combine(self, env=os.environ, keep_string=None) -> MutableMapping:
         """
         Perform a prioritized recursive merge of config files.
 
@@ -279,8 +290,8 @@ class Config(object, metaclass=NewInitCaller):
         :return: dict
         """
         defaults = self._get_defaults()
-        base_config = self.args.get("base_config")
-        if base_config and os.path.exists(base_config):
+        base_configs = filter(os.path.exists, self.args.get("base_config", []))
+        for base_config in base_configs:
             with util.open_file(base_config) as stream:
                 s = stream.read()
                 self._preflight(s)
@@ -300,7 +311,7 @@ class Config(object, metaclass=NewInitCaller):
 
         return defaults
 
-    def _interpolate(self, stream, env, keep_string):
+    def _interpolate(self, stream: str, env: MutableMapping, keep_string: str) -> str:
         env = set_env_from_file(env, self.env_file)
 
         i = interpolation.Interpolator(interpolation.TemplateWithDefaults, env)
@@ -312,8 +323,9 @@ class Config(object, metaclass=NewInitCaller):
                 self.molecule_file, e.place, e.string
             )
             util.sysexit_with_message(msg)
+        return ""
 
-    def _get_defaults(self):
+    def _get_defaults(self) -> MutableMapping:
         if not self.molecule_file:
             scenario_name = "default"
         else:
@@ -359,6 +371,7 @@ class Config(object, metaclass=NewInitCaller):
                     "side_effect": "side_effect.yml",
                     "verify": "verify.yml",
                 },
+                "log": True,
             },
             "scenario": {
                 "name": scenario_name,
@@ -403,9 +416,8 @@ class Config(object, metaclass=NewInitCaller):
             },
         }
 
-    def _preflight(self, data):
-        env = os.environ.copy()
-        env = set_env_from_file(env, self.env_file)
+    def _preflight(self, data: MutableMapping):
+        env = set_env_from_file(os.environ.copy(), self.env_file)
         errors, data = schema_v3.pre_validate(data, env, MOLECULE_KEEP_STRING)
         if errors:
             msg = "Failed to pre-validate.\n\n{}".format(errors)
@@ -431,10 +443,10 @@ def molecule_file(path):
     return os.path.join(path, MOLECULE_FILE)
 
 
-def set_env_from_file(env, env_file):
+def set_env_from_file(env: MutableMapping[str, str], env_file: str) -> MutableMapping:
     """Load environment from file."""
     if env_file and os.path.exists(env_file):
-        env = env.copy()
+        env = copy.copy(env)
         d = util.safe_load_file(env_file)
         for k, v in d.items():
             env[k] = v
@@ -454,12 +466,20 @@ def ansible_version(version: str = "") -> Version:
     """
     if not version:
         proc = run_command(["ansible", "--version"], quiet=True)
-        if proc.returncode == 0:
-            version = proc.stdout.splitlines()[0].split()[1]
-        else:
+        if proc.returncode != 0:
             LOG.fatal(
                 "Unable to find a working copy of ansible executable. Read https://molecule.readthedocs.io/en/latest/installation.html\n%s",
                 proc,
             )
             sysexit(RC_SETUP_ERROR)
+
+        # First line of the `ansible --version` output is:
+        #
+        #  1. `ansible <version>` on ansible < 2.10 and on ansible-base.
+        #  2. `ansible [core <version>]` on ansible-core.
+        #
+        # The code below grabs the last component in that line and strips trailing ] if
+        # present.
+        version = proc.stdout.splitlines()[0].split()[-1].rstrip("]")
+
     return Version(version)
